@@ -1,35 +1,38 @@
+from p2p_python.config import C, V, Debug, PeerToPeerError
+from p2p_python.user import User
+from p2p_python.serializer import dumps
+from p2p_python.tool.traffic import Traffic
+from p2p_python.tool.utils import AESCipher
+from nem_ed25519_rust import generate_keypair, encrypt, decrypt
+from threading import Thread, current_thread, RLock, Event
+from typing import Optional, List
+from logging import getLogger
+from binascii import a2b_hex
+from time import time, sleep
+from queue import Queue
+from io import BytesIO
+import selectors
 import json
 import random
 import socket
 import socks
 import zlib
-import selectors
-from queue import Queue
-from io import BytesIO
-from time import time, sleep
-from logging import getLogger
-from binascii import a2b_hex
-from threading import Thread, current_thread, RLock, Event
-from nem_ed25519_rust import generate_keypair, encrypt, decrypt
-from p2p_python.tool.traffic import Traffic
-from p2p_python.tool.utils import AESCipher
-from p2p_python.config import C, V, Debug, PeerToPeerError
-from p2p_python.user import User
-from p2p_python.serializer import dumps
+
 
 # constant
 SERVER_SIDE = 'Server'
 CLIENT_SIDE = 'Client'
 
-log = getLogger('p2p-python')
+log = getLogger(__name__)
 listen_sel = selectors.DefaultSelector()
 ban_address = list()  # deny connection address
 
 
-class Core:
+class Core(object):
 
     def __init__(self, host=None, listen=15, buffsize=4096):
         assert V.DATA_PATH is not None, 'Setup p2p params before CoreClass init.'
+        assert host is None or host == 'localhost'
         # status params
         self.f_stop = False
         self.f_finish = False
@@ -37,7 +40,7 @@ class Core:
         # working info
         self.start_time = int(time())
         self.number = 0
-        self.user = list()
+        self.user: List[User] = list()
         self.lock = RLock()
         self.host = host  # local=>'localhost', 'global'=>None
         self.core_que = Queue(maxsize=200)
@@ -46,8 +49,6 @@ class Core:
         self.traffic = Traffic()
         self._ping = Event()
         self._ping.set()
-        self.udp_ipv4_sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-        self.udp_ipv6_sock = socket.socket(socket.AF_INET6, socket.SOCK_DGRAM)
 
     def close(self):
         if not self.f_running:
@@ -67,130 +68,23 @@ class Core:
             self._ping.set()
             return r
         except Exception as e:
-            log.debug("Failed ping by {} udp={}".format(e, f_udp))
+            log.debug(f"failed ping by {e} udp={f_udp}")
             self._ping.set()
             return False
 
     def start(self, s_family=socket.AF_UNSPEC):
-
-        def tcp_server_listen(server_sock, mask):
-            try:
-                sock, host_port = server_sock.accept()
-                sock.setblocking(True)
-                Thread(target=self._initial_connection_check, args=(sock, host_port), daemon=True).start()
-                log.info("Server accept from {}".format(host_port))
-            except OSError as e:
-                log.debug("OSError {}".format(e))
-            except Exception as e:
-                log.debug(e, exc_info=Debug.P_EXCEPTION)
-
-        def udp_server_listen(server_sock, mask):
-            try:
-                msg, address = server_sock.recvfrom(8192)
-                msg_len = msg[0]
-                msg_name, msg_body = msg[1:msg_len + 1], msg[msg_len + 1:]
-                user = self.name2user(msg_name.decode())
-                if user is None:
-                    return
-                self.traffic.put_traffic_down(msg_body)
-                msg_body = AESCipher.decrypt(key=user.aeskey, enc=msg_body)
-                if msg_body == b'Ping':
-                    log.info("Get udp accept from {}".format(user))
-                    self.send_msg_body(msg_body=b'Pong', user=user)
-                else:
-                    log.debug("Get udp packet from {}".format(user))
-                    self.core_que.put((user, msg_body))
-            except OSError as e:
-                log.debug("OSError {}".format(e))
-            except Exception as e:
-                log.debug(e, exc_info=Debug.P_EXCEPTION)
-
-        def create_tcp_server_socks():
-            for res in socket.getaddrinfo(self.host, V.P2P_PORT, s_family, socket.SOCK_STREAM, 0,
-                                          socket.AI_PASSIVE):
-                af, sock_type, proto, canon_name, sa = res
-                try:
-                    sock = socket.socket(af, sock_type, proto)
-                    sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
-                except OSError as e:
-                    log.debug("Failed tcp socket.socket {}".format(sa))
-                    continue
-                try:
-                    sock.bind(sa)
-                    sock.listen(self.listen)
-                    sock.setblocking(False)
-                except OSError as e:
-                    try:
-                        sock.shutdown(socket.SHUT_RDWR)
-                        sock.close()
-                    except OSError:
-                        pass
-                    log.debug("Failed tcp bind or listen {}".format(sa))
-                    continue
-                if af == socket.AF_INET or af == socket.AF_INET6:
-                    listen_sel.register(sock, selectors.EVENT_READ, tcp_server_listen)
-                    log.info("New tcp server {} {}".format("IPV4" if sock.family == 2 else "IPV6", sa))
-                else:
-                    log.warning("Not found socket type {}".format(af))
-            if len(listen_sel.get_map()) == 0:
-                log.error('could not open tcp sockets')
-                V.P2P_ACCEPT = False
-
-        def create_udp_server_socks():
-            before_num = len(listen_sel.get_map())
-            for res in socket.getaddrinfo(self.host, V.P2P_PORT, s_family, socket.SOCK_DGRAM, 0,
-                                          socket.AI_PASSIVE):
-                af, sock_type, proto, canon_name, sa = res
-                try:
-                    sock = socket.socket(af, sock_type, proto)
-                except OSError as e:
-                    log.debug("Failed udp socket.socket {}".format(sa))
-                    continue
-                try:
-                    sock.bind(sa)
-                    sock.setblocking(False)
-                except OSError as e:
-                    sock.close()
-                    log.debug("Failed udp bind {}".format(sa))
-                    continue
-                if af == socket.AF_INET or af == socket.AF_INET6:
-                    listen_sel.register(sock, selectors.EVENT_READ, udp_server_listen)
-                    log.info("New udp server {} {}".format("IPV4" if sock.family == 2 else "IPV6", sa))
-                else:
-                    log.warning("Not found socket type {}".format(af))
-            if len(listen_sel.get_map()) == before_num:
-                log.error('could not open udp sockets')
-                V.P2P_UDP_ACCEPT = False
-
-        def sock_listen_loop():
-            while not self.f_stop:
-                try:
-                    listen_map = listen_sel.get_map()
-                    if listen_map is None:
-                        log.debug("Closed.")
-                        return
-                    while len(listen_map) == 0:
-                        sleep(0.5)
-                    events = listen_sel.select()
-                    for key, mask in events:
-                        callback = key.data
-                        callback(key.fileobj, mask)
-                except Exception as e:
-                    log.error(e)
-                    sleep(3)
-
         assert s_family in (socket.AF_INET, socket.AF_INET6, socket.AF_UNSPEC)
         self.traffic.start()
         # Pooling connection
         if V.P2P_ACCEPT:
-            create_tcp_server_socks()
+            create_tcp_server_socks(core=self, s_family=s_family)
         if V.P2P_UDP_ACCEPT:
-            create_udp_server_socks()
+            create_udp_server_socks(core=self, s_family=s_family)
         # listen socket ipv4/ipv6
         if V.P2P_ACCEPT or V.P2P_UDP_ACCEPT:
-            Thread(target=sock_listen_loop, name='Listen', daemon=True).start()
+            Thread(target=sock_listen_loop, args=(self,), name='Listen', daemon=True).start()
         else:
-            log.info('You set p2p accept flag False.')
+            log.info("set p2p accept flag = False")
         self.f_running = True
 
     def get_server_header(self):
@@ -206,7 +100,7 @@ class Core:
         }
 
     def create_connection(self, host, port):
-        sock = host_port = None
+        sock = None
         try:
             for res in socket.getaddrinfo(host, port, socket.AF_UNSPEC, socket.SOCK_STREAM):
                 af, socktype, proto, canonname, host_port = res
@@ -231,7 +125,6 @@ class Core:
                     break
                 except OSError:
                     try:
-                        sock.shutdown(socket.SHUT_RDWR)
                         sock.close()
                     except OSError:
                         pass
@@ -239,47 +132,62 @@ class Core:
             else:
                 # create no connection
                 return False
-            log.debug("Success connection create to {}".format(host_port))
-            # 平文を受取る
-            msg = sock.recv(self.buffsize)
-            if msg != b'hello':
-                raise PeerToPeerError('first plain msg not correct {}'.format(msg))
-            # ヘッダーを送る
+            log.debug(f"success create connection to {host_port}")
+            # 1. receive plain message
+            try:
+                msg = sock.recv(self.buffsize)
+                if msg != b'hello':
+                    raise PeerToPeerError('first plain msg not correct? {}'.format(msg))
+            except socket.timeout:
+                raise PeerToPeerError('timeout on first plain msg receive')
+            # 2. send my header
             send = json.dumps(self.get_server_header()).encode()
             sock.sendall(send)
             self.traffic.put_traffic_up(send)
-            # 公開鍵を受取る
-            my_sec, my_pub = generate_keypair()
-            receive = sock.recv(self.buffsize)
-            self.traffic.put_traffic_down(receive)
-            other_pk = json.loads(receive.decode())['public-key']
+            # 3. receive public key
+            try:
+                my_sec, my_pub = generate_keypair()
+                receive = sock.recv(self.buffsize)
+                self.traffic.put_traffic_down(receive)
+                msg = json.loads(receive.decode())
+            except socket.timeout:
+                raise PeerToPeerError('timeout on public key receive')
+            except json.JSONDecodeError:
+                raise PeerToPeerError('json decode error on public key receive')
+            other_pk = msg['public-key']
             other_pub = a2b_hex(other_pk)
-            # 公開鍵を送る
+            # 4. send public key
             send = json.dumps({'public-key': my_pub.hex()}).encode()
             sock.sendall(send)
             self.traffic.put_traffic_up(send)
-            # AESKEYとヘッダーを取得し復号化する
-            receive = sock.recv(self.buffsize)
-            self.traffic.put_traffic_down(receive)
-            data = json.loads(decrypt(my_sec, other_pub, receive).decode())
+            # 5. Get AES key and header and decrypt
+            try:
+                receive = sock.recv(self.buffsize)
+                self.traffic.put_traffic_down(receive)
+                dec = decrypt(my_sec, other_pub, receive)
+                data = json.loads(dec.decode())
+            except socket.timeout:
+                raise PeerToPeerError('timeout on AES key and header receive')
+            except json.JSONDecodeError:
+                raise PeerToPeerError('json decode error on AES key and header receive')
             aeskey, header = data['aes-key'], data['header']
-            log.debug("Success ase-key receive {}".format(host_port))
-            # ユーザーを作成する
+            # 6. generate new user
             with self.lock:
                 new_user = User(self.number, sock, host_port, aeskey, C.T_CLIENT)
                 new_user.deserialize(header)
-                # headerのチェック
+                # 7. check header
                 if new_user.network_ver != V.NETWORK_VER:
                     raise PeerToPeerError('Don\'t same network version [{}!={}]'.format(
                         new_user.network_ver, V.NETWORK_VER))
                 self.number += 1
-            # Acceptシグナルを送る
+            # 8. send accept signal
             encrypted = AESCipher.encrypt(new_user.aeskey, b'accept')
             sock.sendall(encrypted)
             self.traffic.put_traffic_up(encrypted)
 
-            log.info("New connection to \"{}\" {}".format(new_user.name, new_user.get_host_port()))
-            Thread(target=self._receive_msg, name='C:' + new_user.name, args=(new_user,), daemon=True).start()
+            # 9. accept connection
+            log.info(f"New connection to {new_user.name} {new_user.get_host_port()}")
+            Thread(target=self.receive_loop, name='C:' + new_user.name, args=(new_user,), daemon=True).start()
 
             c = 20
             while new_user not in self.user and c > 0:
@@ -290,32 +198,26 @@ class Core:
                 return False
             else:
                 return True
-        except json.JSONDecodeError:
-            error = "Json decode error."
         except PeerToPeerError as e:
-            error = "NewConnectionError {} {}".format(host_port, e)
+            msg = "peer2peer error, {} ({})".format(e, host)
         except ConnectionRefusedError as e:
-            error = "ConnectionRefusedError {} {}".format(host_port, e)
+            msg = "connection refused error, {} ({})".format(e, host)
         except ValueError as e:
-            error = "ValueError: {} {}".format(host_port, e)
+            msg = "ValueError: {} {}".format(host, e)
         except Exception as e:
-            log.debug("NewConnectionError", exc_info=True)
-            error = "NewConnectionError {} {}".format(host_port, e)
+            log.error("NewConnectionError", exc_info=True)
+            msg = "NewConnectionError {} {}".format(host, e)
 
         # close socket
-        log.error(error)
+        log.debug(msg)
         try:
-            sock.sendall(error.encode())
-        except Exception as e:
-            pass
-        try:
-            sock.shutdown(socket.SHUT_RDWR)
+            sock.sendall(msg.encode())
             sock.close()
-        except OSError:
+        except Exception as e:
             pass
         return False
 
-    def remove_connection(self, user, reason=None):
+    def remove_connection(self, user, reason=None) -> bool:
         if user is None:
             return False
         try:
@@ -327,15 +229,15 @@ class Core:
         with self.lock:
             if user in self.user:
                 self.user.remove(user)
-                log.debug("remove connection to {} by '{}'".format(user.name, reason))
+                log.debug(f"remove connection to {user.name} by {reason}")
                 return True
             else:
-                log.debug("failed remove connection by '{}', not found {}".format(reason, user.name))
+                log.debug(f"failed remove connection by {reason}, not found {user.name}")
                 return False
 
     def send_msg_body(self, msg_body, user=None, status=200, f_udp=False, f_pro_force=False):
         # StatusCode: https://ja.wikipedia.org/wiki/HTTPステータスコード
-        assert type(msg_body) == bytes, 'msg_body is bytes'
+        assert isinstance(msg_body, bytes), 'msg_body is bytes'
         assert 200 <= status < 600, 'Not found status code {}'.format(status)
 
         # get client
@@ -369,85 +271,97 @@ class Core:
         msg_body = AESCipher.encrypt(key=user.aeskey, raw=msg_body)
         send_data = name_len + V.SERVER_NAME.encode() + msg_body
         host_port = user.get_host_port()
-        if len(host_port) == 2:
-            self.udp_ipv4_sock.sendto(send_data, host_port)
-        else:
-            self.udp_ipv6_sock.sendto(send_data, host_port)
+        sock_family = socket.AF_INET if len(host_port) == 2 else socket.AF_INET6
+        with socket.socket(sock_family, socket.SOCK_DGRAM) as sock:
+            sock.sendto(send_data, host_port)
         self.traffic.put_traffic_up(send_data)
 
-    def _initial_connection_check(self, sock, host_port):
+    def initial_connection_check(self, sock, host_port):
         current_thread().setName('InitCheck')
         sock.settimeout(10)
         try:
-            # 平文を送る
+            # 1. send plain message
             sock.sendall(b'hello')
-            # ヘッダーを受取る
-            received = sock.recv(self.buffsize)
-            if len(received) == 0:
-                raise ConnectionAbortedError('zero msg, connection closed.')
-            self.traffic.put_traffic_down(received)
-            header = json.loads(received.decode())
+            # 2. receive other's header
+            try:
+                received = sock.recv(self.buffsize)
+                if len(received) == 0:
+                    raise PeerToPeerError('empty msg receive')
+                header = json.loads(received.decode())
+            except socket.timeout:
+                raise PeerToPeerError('timeout on other\'s header receive')
+            except json.JSONDecodeError:
+                raise PeerToPeerError('json decode error on other\'s header receive')
+            # 3. generate new user
             with self.lock:
-                new_user = User(
-                    self.number, sock, host_port, aeskey=AESCipher.create_key(), sock_type=C.T_SERVER)
+                new_user = User(self.number, sock, host_port, AESCipher.create_key(), C.T_SERVER)
                 self.number += 1
-            new_user.deserialize(header)
-            if new_user.name == V.SERVER_NAME:
-                raise ConnectionAbortedError('Same origin connection.')
-            # こちらの公開鍵を送る
+                new_user.deserialize(header)
+                if new_user.name == V.SERVER_NAME:
+                    raise ConnectionAbortedError('Same origin connection.')
+            # 4. send my public key
             my_sec, my_pub = generate_keypair()
             send = json.dumps({'public-key': my_pub.hex()}).encode()
             sock.sendall(send)
             self.traffic.put_traffic_up(send)
-            # 公開鍵を取得する
-            receive = sock.recv(self.buffsize)
-            self.traffic.put_traffic_down(receive)
-            if len(receive) == 0:
-                raise ConnectionAbortedError('received msg is zero.')
-            other_pk = json.loads(receive.decode())['public-key']
-            other_pub = a2b_hex(other_pk)
-            # AESKEYとHeaderを暗号化して送る
-            send = json.dumps({'aes-key': new_user.aeskey, 'header': self.get_server_header()})
+            # 5. receive public key
+            try:
+                receive = sock.recv(self.buffsize)
+                self.traffic.put_traffic_down(receive)
+                if len(receive) == 0:
+                    raise ConnectionAbortedError('received msg is zero.')
+                data = json.loads(receive.decode())
+            except socket.timeout:
+                raise PeerToPeerError('timeout on public key receive')
+            except json.JSONDecodeError:
+                raise PeerToPeerError('json decode error on public key receive')
+            other_pub = a2b_hex(data['public-key'])
+            # 6. encrypt and send AES key and header
+            send = json.dumps({
+                'aes-key': new_user.aeskey,
+                'header': self.get_server_header(),
+            })
             encrypted = encrypt(my_sec, other_pub, send.encode())
             sock.send(encrypted)
             self.traffic.put_traffic_up(encrypted)
-            # Accept信号を受け取る
-            encrypted = sock.recv(self.buffsize)
-            self.traffic.put_traffic_down(encrypted)
+            # 7. receive accept signal
+            try:
+                encrypted = sock.recv(self.buffsize)
+                self.traffic.put_traffic_down(encrypted)
+            except socket.timeout:
+                raise PeerToPeerError('timeout on accept signal receive')
             receive = AESCipher.decrypt(new_user.aeskey, encrypted)
             if receive != b'accept':
-                raise ConnectionAbortedError('Not accept signal.')
-            # Accept connection
-            log.info("New connection from \"{}\" {}".format(new_user.name, new_user.get_host_port()))
-            Thread(target=self._receive_msg, name='S:' + new_user.name, args=(new_user,), daemon=True).start()
+                raise ConnectionAbortedError('Not accept signal!')
+
+            # 8. accept connection
+            log.info(f"New connection from {new_user.name} {new_user.get_host_port()}")
+            Thread(target=self.receive_loop, name='S:' + new_user.name, args=(new_user,), daemon=True).start()
             # Port accept check
             sleep(10)
             if new_user in self.user:
                 self.is_reachable(new_user)
             return
         except ConnectionAbortedError as e:
-            error = "ConnectionAbortedError, {}".format(e)
-        except json.decoder.JSONDecodeError as e:
-            error = "JSONDecodeError, {}".format(e)
-        except socket.timeout:
-            error = "socket.timeout"
+            msg = "connection aborted error, {} ({})".format(e, host_port[0])
+        except PeerToPeerError as e:
+            msg = "peer2peer error, {} ({})".format(e, host_port[0])
         except Exception as e:
-            log.debug("InitialConnCheck", exc_info=True)
-            error = "InitialConnCheck: {}".format(e)
+            log.error("InitialConnCheck", exc_info=True)
+            msg = "InitialConnCheck: {}".format(e)
+
         # close socket
-        error = "Close on initial check " + error
-        log.error(error)
+        log.debug(msg)
         try:
-            sock.sendall(error.encode())
+            sock.sendall(msg.encode())
         except Exception:
             pass
         try:
-            sock.shutdown(socket.SHUT_RDWR)
             sock.close()
         except OSError:
             pass
 
-    def _receive_msg(self, user):
+    def receive_loop(self, user):
         # Accept connection
         with self.lock:
             for check_user in self.user:
@@ -462,10 +376,10 @@ class Core:
                     self.remove_connection(check_user, error)
                     log.info(error)
             self.user.append(user)
-        log.info("Accept connection \"{}\"".format(user.name))
+        log.info(f"accept connection {user.name}")
 
         try:
-            user.sock.settimeout(5.0)
+            user.sock.settimeout(10)
         except OSError:
             error = 'settimeout failed on _receive_msg'
             self.remove_connection(user, error)
@@ -528,10 +442,10 @@ class Core:
                 msg_body = AESCipher.decrypt(key=user.aeskey, enc=msg_body)
                 msg_body = zlib.decompress(msg_body)
                 if msg_body == b'Ping':
-                    log.debug("receive ping from {}".format(user.name))
+                    log.debug(f"receive Ping from {user.name}")
                     self.send_msg_body(b'Pong', user)
                 elif msg_body == b'Pong':
-                    log.debug("receive Pong from {}".format(user.name))
+                    log.debug(f"receive Pong from {user.name}")
                     self._ping.set()
                 else:
                     self.core_que.put((user, msg_body))
@@ -556,7 +470,7 @@ class Core:
         if not bio.closed:
             bio.close()
         if not self.remove_connection(user, error):
-            log.debug("Failed remove user {}".format(user.name))
+            log.debug(f"failed remove user {user.name}")
 
     def is_reachable(self, new_user):
         # Check connect to the user TCP/UDP port
@@ -573,7 +487,6 @@ class Core:
         except OSError:
             f_tcp = False
         try:
-            sock.shutdown(socket.SHUT_RDWR)
             sock.close()
         except OSError:
             pass
@@ -581,25 +494,156 @@ class Core:
         f_changed = False
         # reflect user status
         if f_tcp is not new_user.p2p_accept:
-            log.debug("{} Update TCP accept status [{}>{}]".format(new_user, new_user.p2p_accept, f_tcp))
+            log.debug(f"{new_user} Update TCP accept status {new_user.p2p_accept}>{f_tcp}")
             new_user.p2p_accept = f_tcp
             f_changed = True
         if f_udp is not new_user.p2p_udp_accept:
-            log.debug("{} Update UDP accept status [{}>{}]".format(new_user, new_user.p2p_udp_accept, f_udp))
+            log.debug(f"{new_user} Update UDP accept status {new_user.p2p_udp_accept}>{f_udp}")
             new_user.p2p_udp_accept = f_udp
             f_changed = True
         # if f_changed:
         #    log.info("{} Change TCP/UDP accept status tcp={} udp={}"
         #                 .format(new_user, f_tcp, f_udp))
 
-    def name2user(self, name):
+    def name2user(self, name) -> Optional[User]:
         for user in self.user:
             if user.name == name:
                 return user
         return None
 
-    def host_port2user(self, host_port):
+    def host_port2user(self, host_port) -> Optional[User]:
         for user in self.user:
             if host_port == user.get_host_port():
                 return user
         return None
+
+
+"""socket connection functions
+"""
+
+
+def tcp_server_listen(core: Core):
+    """TCP server new connection control"""
+    def handle(server_sock, mask):
+        try:
+            sock, host_port = server_sock.accept()
+            sock.setblocking(True)
+            Thread(target=core.initial_connection_check, args=(sock, host_port), daemon=True).start()
+            log.info(f"server accept from {host_port}")
+        except OSError as e:
+            log.debug(f"OSError {str(e)}")
+        except Exception as e:
+            log.debug(e, exc_info=Debug.P_EXCEPTION)
+    return handle
+
+
+def udp_server_listen(core: Core):
+    """UDP server new connection control"""
+    def handle(server_sock, mask):
+        try:
+            msg, address = server_sock.recvfrom(8192)
+            msg_len = msg[0]
+            msg_name, msg_body = msg[1:msg_len + 1], msg[msg_len + 1:]
+            user = core.name2user(msg_name.decode())
+            if user is None:
+                return
+            core.traffic.put_traffic_down(msg_body)
+            msg_body = AESCipher.decrypt(key=user.aeskey, enc=msg_body)
+            if msg_body == b'Ping':
+                log.info(f"get udp accept from {user}")
+                core.send_msg_body(msg_body=b'Pong', user=user)
+            else:
+                log.debug(f"get udp packet from {user}")
+                core.core_que.put((user, msg_body))
+        except OSError as e:
+            log.debug(f"OSError {str(e)}")
+        except Exception as e:
+            log.debug(e, exc_info=Debug.P_EXCEPTION)
+    return handle
+
+
+def create_tcp_server_socks(core: Core, s_family):
+    """create new TCP socket server"""
+    for res in socket.getaddrinfo(core.host, V.P2P_PORT, s_family, socket.SOCK_STREAM, 0, socket.AI_PASSIVE):
+        af, sock_type, proto, canon_name, sa = res
+        try:
+            sock = socket.socket(af, sock_type, proto)
+            sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+        except OSError as e:
+            log.debug(f"failed tcp socket {sa}")
+            continue
+        try:
+            sock.bind(sa)
+            sock.listen(core.listen)
+            sock.setblocking(False)
+        except OSError as e:
+            try:
+                sock.close()
+            except OSError:
+                pass
+            log.debug(f"failed tcp bind or listen {sa}")
+            continue
+        if af == socket.AF_INET or af == socket.AF_INET6:
+            listen_sel.register(sock, selectors.EVENT_READ, tcp_server_listen(core))
+            sock_type = "IPV4" if sock.family == 2 else "IPV6"
+            log.info(f"new tcp server {sock_type} {sa}")
+        else:
+            log.warning(f"not found socket type {af}")
+    if len(listen_sel.get_map()) == 0:
+        log.error("could not open tcp sockets")
+        V.P2P_ACCEPT = False
+
+
+def create_udp_server_socks(core: Core, s_family):
+    """create new UDP socket server"""
+    before_num = len(listen_sel.get_map())
+    for res in socket.getaddrinfo(core.host, V.P2P_PORT, s_family, socket.SOCK_DGRAM, 0, socket.AI_PASSIVE):
+        af, sock_type, proto, canon_name, sa = res
+        try:
+            sock = socket.socket(af, sock_type, proto)
+        except OSError as e:
+            log.debug(f"failed udp socket {sa}")
+            continue
+        try:
+            sock.bind(sa)
+            sock.setblocking(False)
+        except OSError as e:
+            sock.close()
+            log.debug(f"failed udp bind {sa}")
+            continue
+        if af == socket.AF_INET or af == socket.AF_INET6:
+            listen_sel.register(sock, selectors.EVENT_READ, udp_server_listen(core))
+            sock_type = "IPV4" if sock.family == 2 else "IPV6"
+            log.info(f"new udp server {sock_type} {sa}")
+        else:
+            log.warning(f"not found socket type {af}")
+    if len(listen_sel.get_map()) == before_num:
+        log.error("could not open udp sockets")
+        V.P2P_UDP_ACCEPT = False
+
+
+def sock_listen_loop(core: Core):
+    """TCP/UDP server's selector"""
+    while not core.f_stop:
+        try:
+            listen_map = listen_sel.get_map()
+            if listen_map is None:
+                log.debug("close sock listen loop")
+                return
+            while len(listen_map) == 0:
+                sleep(0.5)
+            events = listen_sel.select()
+            for key, mask in events:
+                callback = key.data
+                callback(key.fileobj, mask)
+        except Exception as e:
+            log.error(e)
+            sleep(3)
+
+
+__all__ = [
+    "SERVER_SIDE",
+    "CLIENT_SIDE",
+    "ban_address",
+    "Core",
+]
