@@ -1,6 +1,6 @@
 from p2p_python.serializer import stream_unpacker, dump
-from time import time
 from logging import getLogger
+from time import time
 import os
 
 # For AES
@@ -9,7 +9,7 @@ from Cryptodome.Util.Padding import pad, unpad
 from Cryptodome import Random
 from base64 import b64encode, b64decode
 
-log = getLogger('p2p-python')
+log = getLogger(__name__)
 
 
 class EventIgnition:
@@ -74,7 +74,7 @@ class AESCipher:
         return raw
 
 
-class Peers:
+class PeerData(object):
 
     def __init__(self, path):
         """recode all node, don't remove"""
@@ -127,5 +127,5 @@ class Peers:
 __all__ = [
     "EventIgnition",
     "AESCipher",
-    "Peers",
+    "PeerData",
 ]
